==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/el.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Δραστηριότητες",
    "An error occurred while loading activities" : "Παρουσιάστηκε σφάλμα κατά την φόρτωση των δραστηριοτήτων",
    "No activity yet" : "Καμία δραστηριότητα ακόμα",
    "Load more activities" : "Φόρτωση περισσότερων δραστηριοτήτων",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C",
    "{name} (invisible)" : "{name} (αόρατος/η)",
    "{name} (restricted)" : "{name} (περιορισμένη πρόσβαση)",
    "in {path}" : "στην {path}",
    "This stream will show events like additions, changes & shares" : "Αυτή η ροή θα δείξει γεγονότα όπως προσθήκες, αλλαγές και διαμοιρασμούς",
    "There are no events for this filter" : "Δεν υπάρχουν γεγονότα για αυτό το φίλτρο",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "Personal activity feed for %s" : "Προσωπική δραστηριότητα ροής πληροφοριών για %s",
    "Your feed URL is invalid" : "Η διεύθυνση ροής πληροφοριών URL δεν είναι έγκυρη",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "Settings have been updated." : "Οι ρυθμίσεις έχουν ενημερωθεί.",
    "Mail" : "Ταχυδρομείο",
    "Stream" : "Ροή",
    "All activities" : "Όλες οι δραστηριότητες",
    "By others" : "Από άλλους",
    "By you" : "Από εσάς",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "Hello %s" : "Γεια σας %s",
    "Hello %s," : "Γεια σας %s,",
    "There was some activity at %s" : "Υπήρξε δραστηριότητα στο %s",
    "_and %n more _::_and %n more _" : ["και %n επιπλέον","και %n επιπλέον"],
    "Activity notification" : "Ειδοποίηση δραστηριότητας",
    ", " : ", ",
    "%s and %s" : "%s και %s",
    "Activity" : "Δραστηριότητα",
    "Activity feed" : "Ροή Δραστηριότητας",
    "Configure the default activity settings for new users." : "Διαμορφώστε τις προεπιλεγμένες ρυθμίσεις δραστηριότητας για τους νέους χρήστες.",
    "List your own actions in the stream" : "Δημιουργία λίστας των δραστηριοτήτων σας στην ροή",
    "Notify about your own actions via email" : "Ενημερωθείτε για τις δράσεις σας μέσω email",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω email.",
    "Send emails:" : "Αποστολή μηνυμάτων email:",
    "Hourly" : "Ωριαία",
    "Daily" : "Καθημερινά",
    "Weekly" : "Εβδομαδιαία",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Επιλέξτε για ποιες δραστηριότητες θέλετε να λαμβάνετε ειδοποιήσεις μέσω email, και ποιες θα εμφανίζονται στην εφαρμογή δραστηριοτήτων ροής.",
    "Settings" : "Ρυθμίσεις",
    "Enable RSS feed" : "Ενεργοποίηση ροής πληροφοριών RSS",
    "No more events to load" : "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
    "Files" : "Αρχεία",
    "Error loading activities" : "Σφάλμα φόρτωσης δραστηριοτήτων",
    "No activities" : "Καμία δραστηριότητα",
    "You are receiving this email because the following things happened at %s" : "Λαμβάνετε αυτό το email διότι συνέβησαν τα ακόλουθα στο %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* και %n επιπλέον","* και %n επιπλέον"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/el.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Δραστηριότητες",
    "An error occurred while loading activities" : "Παρουσιάστηκε σφάλμα κατά την φόρτωση των δραστηριοτήτων",
    "No activity yet" : "Καμία δραστηριότητα ακόμα",
    "Load more activities" : "Φόρτωση περισσότερων δραστηριοτήτων",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C",
    "Home" : "Αρχική",
    "{name} (invisible)" : "{name} (αόρατος/η)",
    "{name} (restricted)" : "{name} (περιορισμένη πρόσβαση)",
    "in {path}" : "στην {path}",
    "This stream will show events like additions, changes & shares" : "Αυτή η ροή θα δείξει γεγονότα όπως προσθήκες, αλλαγές και διαμοιρασμούς",
    "There are no events for this filter" : "Δεν υπάρχουν γεγονότα για αυτό το φίλτρο",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "Open file" : "Άνοιγμα αρχείου",
    "Personal activity feed for %s" : "Προσωπική δραστηριότητα ροής πληροφοριών για %s",
    "Your feed URL is invalid" : "Η διεύθυνση ροής πληροφοριών URL δεν είναι έγκυρη",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "Settings have been updated." : "Οι ρυθμίσεις έχουν ενημερωθεί.",
    "Mail" : "Ταχυδρομείο",
    "Stream" : "Ροή",
    "All activities" : "Όλες οι δραστηριότητες",
    "By others" : "Από άλλους",
    "By you" : "Από εσάς",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "Hello %s" : "Γεια σας %s",
    "Hello %s," : "Γεια σας %s,",
    "There was some activity at %s" : "Υπήρξε δραστηριότητα στο %s",
    "_and %n more _::_and %n more _" : ["και %n επιπλέον","και %n επιπλέον"],
    "Activity notification" : "Ειδοποίηση δραστηριότητας",
    ", " : ", ",
    "%s and %s" : "%s και %s",
    "Activity" : "Δραστηριότητα",
    "Activity feed" : "Ροή Δραστηριότητας",
    "Send activity emails" : "Αποστολή μηνυμάτων δραστηριοτήτων",
    "Default settings" : "Προεπιλεγμένες ρυθμίσεις",
    "Configure the default activity settings for new users." : "Διαμορφώστε τις προεπιλεγμένες ρυθμίσεις δραστηριότητας για τους νέους χρήστες.",
    "List your own actions in the stream" : "Δημιουργία λίστας των δραστηριοτήτων σας στην ροή",
    "Notify about your own actions via email" : "Ενημερωθείτε για τις δράσεις σας μέσω email",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε ειδοποιήσεις μέσω email.",
    "Send emails:" : "Αποστολή μηνυμάτων email:",
    "As soon as possible" : "Το συντομότερο δυνατό",
    "Hourly" : "Ωριαία",
    "Daily" : "Καθημερινά",
    "Weekly" : "Εβδομαδιαία",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Επιλέξτε για ποιες δραστηριότητες θέλετε να λαμβάνετε ειδοποιήσεις μέσω email, και ποιες θα εμφανίζονται στην εφαρμογή δραστηριοτήτων ροής.",
    "Choose which activities you want to see in your stream." : "Διαλέξτε ποιες δραστηριότητες θέλετε να βλέπετε στη ροή σας.",
    "Settings" : "Ρυθμίσεις",
    "Enable RSS feed" : "Ενεργοποίηση ροής πληροφοριών RSS",
    "RSS feed" : "Ροή RSS",
    "No more events to load" : "Δεν υπάρχουν άλλα γεγονότα προς φόρτωση",
    "Files" : "Αρχεία",
    "Error loading activities" : "Σφάλμα φόρτωσης δραστηριοτήτων",
    "No activities" : "Καμία δραστηριότητα",
    "You are receiving this email because the following things happened at %s" : "Λαμβάνετε αυτό το email διότι συνέβησαν τα ακόλουθα στο %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* και %n επιπλέον","* και %n επιπλέον"]
},
"nplurals=2; plural=(n != 1);");
